package djmil.cordacheckers.api;

import java.net.URI;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.security.core.annotation.AuthenticationPrincipal;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.util.UriComponentsBuilder;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.JsonMappingException;

import djmil.cordacheckers.cordaclient.CordaClient;
import djmil.cordacheckers.cordaclient.dao.GameView;
import djmil.cordacheckers.cordaclient.dao.HoldingIdentity;
import djmil.cordacheckers.cordaclient.dao.Stone;
import djmil.cordacheckers.cordaclient.dao.flow.arguments.ReqGameProposalCreate;
import djmil.cordacheckers.user.HoldingIdentityResolver;
import djmil.cordacheckers.user.User;

@RestController
@RequestMapping("api/gameproposal")
public class GameProposalController {

    @Autowired
    CordaClient cordaClient;

    @Autowired
    HoldingIdentityResolver holdingIdentityResolver;

    @PostMapping()
    public ResponseEntity<GameView> createGameProposal(
            @AuthenticationPrincipal User sender,
            @RequestBody ReqGameProposalCreate gpRequest,
            UriComponentsBuilder ucb) throws JsonMappingException, JsonProcessingException {

        final HoldingIdentity gpSender = sender.getHoldingIdentity();
        final HoldingIdentity gpReceiver = holdingIdentityResolver.getByUsername(gpRequest.opponentName());
        final Stone.Color gpReceiverColor = gpRequest.opponentColor();

        // GiteaIssue #4: Exception handling
        GameView gameStateView = cordaClient.gameProposalCreate(
                gpSender,
                gpReceiver,
                gpReceiverColor,
                // gpRequest.board() // GireaIssue #3: use provided board configuration
                gpRequest.message());

        URI locationOfNewGameProposal = ucb
                .path("api/gameproposal/{id}")
                .buildAndExpand(gameStateView.uuid())
                .toUri();

        return ResponseEntity
                .created(locationOfNewGameProposal)
                .body(gameStateView);
    }

}