package djmil.cordacheckers.contracts;

import static djmil.cordacheckers.contracts.GameCommand.requireThat;
import static djmil.cordacheckers.contracts.UtxoLedgerTransactionUtil.getSingleCommand;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import net.corda.v5.ledger.utxo.transaction.UtxoLedgerTransaction;

public class GameBoardContract implements net.corda.v5.ledger.utxo.Contract {
    
    private final static Logger log = LoggerFactory.getLogger(GameBoardContract.class);

    @Override
    public void verify(UtxoLedgerTransaction trx) {
        log.info("GameBoardContract verify");

        requireThat(trx.getCommands().size() == 1, GameCommand.REQUIRE_SINGLE_COMMAND);
        final GameCommand command = getSingleCommand(trx, GameCommand.class);

        switch (command.getAction()) {
            case GAME_PROPOSAL_ACCEPT:
                command.validateGameProposalAccept(trx);
                break;
        
            case MOVE:
                command.validateMove(trx, command.getMove());
                break;

            case SURRENDER:
                command.validateSurrender(trx);
                break;

            case CLAIM_VICTORY:
                command.validateClaimVictory(trx);
                break;

            case DRAW_REQUEST:
                command.validateDrawRequest(trx);
                break;
            
            case DRAW_ACCEPT:
                command.validateDrawAcquire(trx);
                break;

            case DRAW_REJECT:
                command.validateDrawDecline(trx);
                break;

            default:
                throw new GameCommand.ActionException();
        }
    }

}
